@@ -158,11 +158,10 @@ class Gateway(object):
         if ':' not in data:
             raise Exception('Invalid data returned: {}'.format(data))
 
-        print(data)
         result = data.split(':', 2)
         info = dict()
         info['paymentID'] = result[0] or None
-        info['paymentURL'] = result[1] + result[2] or None
+        info['paymentURL'] = '{}:{}'.format(result[1], result[2]) or None
 
         return info
 
